#
# spec file for package umbrello
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%ifarch %{arm} aarch64 %{ix86} x86_64 %{mips} %{riscv}
%bcond_without kdevelop
%endif
# Latest stable Applications (e.g. 17.08 in KA, but 17.11.80 in KUA)
%{!?_kapp_version: %define _kapp_version %(echo %{version}| awk -F. '{print $1"."$2}')}
%bcond_without released
Name:           umbrello
Version:        22.12.3
Release:        bp156.2.28
Summary:        UML Modeller
License:        GPL-2.0-only AND GFDL-1.2-only AND GPL-3.0-or-later
URL:            https://apps.kde.org/umbrello
Source:         https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  extra-cmake-modules
%if %{with kdevelop}
BuildRequires:  kdevelop5-pg-qt
BuildRequires:  kdevplatform-devel
%endif
BuildRequires:  libxml2-devel
BuildRequires:  libxslt-devel
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF5Archive)
BuildRequires:  cmake(KF5Completion)
BuildRequires:  cmake(KF5Config)
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5Crash)
BuildRequires:  cmake(KF5DocTools)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5IconThemes)
BuildRequires:  cmake(KF5ItemModels)
BuildRequires:  cmake(KF5KCMUtils)
BuildRequires:  cmake(KF5KDELibs4Support)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5TextEditor)
BuildRequires:  cmake(KF5ThreadWeaver)
BuildRequires:  cmake(KF5WidgetsAddons)
BuildRequires:  cmake(KF5WindowSystem)
BuildRequires:  cmake(KF5XmlGui)
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5PrintSupport)
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  cmake(Qt5Test)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5Xml)
Obsoletes:      umbrello5 < %{version}
Provides:       umbrello5 = %{version}

%description
Umbrello is a UML modelling application.

%lang_package

%prep
%autosetup -p1

%build
%ifarch ppc64
RPM_OPT_FLAGS="%{optflags} -mminimal-toc"
%endif
export CXXFLAGS="%{optflags} -fPIC"
export CFLAGS="%{optflags} -fPIC"

%cmake_kf5 -d build -- -DBUILD_KF5=ON
%cmake_build

%install
%kf5_makeinstall -C build

%find_lang %{name} --with-man --all-name
%{kf5_find_htmldocs}

%suse_update_desktop_file org.kde.umbrello Development Design

%files
%license COPYING COPYING.DOC
%doc README
%doc %lang(en) %{_kf5_htmldir}/en/umbrello
%{_kf5_applicationsdir}/org.kde.umbrello.desktop
%{_kf5_appstreamdir}/org.kde.umbrello.appdata.xml
%{_kf5_bindir}/po2xmi5
%{_kf5_bindir}/umbrello5
%{_kf5_bindir}/xmi2pot5
%{_kf5_iconsdir}/hicolor/*/*/umbrello*
%{_kf5_iconsdir}/hicolor/*/mimetypes/application-x-uml.png
%{_kf5_sharedir}/umbrello5/

%files lang -f %{name}.lang

%changelog
* Tue Feb 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.3/
* Tue Jan 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.2/
* Tue Jan  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.1/
* Fri Dec  2 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.0/
* Sat Nov 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.90
  * New feature release
* Sat Nov 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.80
  * New feature release
* Tue Nov  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.3/
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.2/
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.1/
* Sun Aug 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.0/
* Fri Aug  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.90
  * New feature release
* Sat Jul 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.80
  * New feature release
* Tue Jul  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.3/
* Wed Jun  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.2/
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.1/
* Mon Apr 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.0/
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.90
  * New feature release
* Wed Mar 23 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.80
  * New feature release
- Too many changes since 21.12.3, only listing bugfixes:
  * Fix "Data type with modifiers are space sensitive" (kde#369464)
  * Fix "request: restore undo/redo buttons missing in KF5 build" (kde#449662)
  * Fix "User Interface: Text / line / fill color are reset to hard coded values" (kde#450472)
  * Improve predictability/reliability of saving to the resource file" (kde#450470)
  * Fix "C++ importer does not recognize 'final' keyword" (kde#397666)
  * Fix "[C++ import] Type std::string is created multiple times" (kde#450196)
  * Fix for "request: GUI improvement diagram toolbar" (kde#449629)
  * Finalize "C#: Windows Forms classes are not imported" and fix "C# importer
    doesn't support properties" (kde#449268)
  * Fix 'Crashes on cancelling the creation of a new class with the "Creation"
    tool in sequence diagram' (kde#443580)
  * umlwidgets/associationwidget.{h,cpp}: Fix line attachments. (kde#449463)
  * Fix "Python class functions return value wrong in class widget" (kde#449462)
  * Fix "Code import wizard: python wrong function return" (kde#449297)
  * Fix crash importing Pascal code via import wizard: (kde#449129)
  * Completion of fix for "Diagram objects moved to inside enclosing
    package become invisible" (kde#447661)
- Drop patch, now upstream
  * 0001-Make-QtWebKit-usage-in-WelcomePage-optional-with-QTe.patch
* Tue Mar  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.3/
- No code change since 21.12.2
* Tue Feb  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.2/
- No code change since 21.12.1
* Tue Jan  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.1/
- No code change since 21.12.0
* Fri Dec  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.0/
- No code change since 21.11.90
* Sat Nov 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.90
  * New feature release
- Changes since 21.11.80:
  * umbrello/dialogs/dialog_utils.cpp function remakeTagEditFields : Address compiler warning about unused parameter `o`.
  * https://scan.coverity.com/projects/3327 Coverity fixes listed by CID :
* Sat Nov 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.80
  * New feature release
- Changes since 21.08.3:
  * umbrello/umbrello.kcfg : Minor tweak to UI Options - Line Color.
  * Fix "Exiting color change popup via Cancel modifies the selected diagram object" (kde#443679)
  * umbrello/umbrello.kcfg - In group "UI Options" tone down Fill Color and Line Color.
  * umbrello/menus/listpopupmenu.cpp - In function insert(const MenuType, KMenu*) remove useless comment.
  * https://scan.coverity.com/projects/3327 Coverity fixes listed by CID :
  * Address remaining trivial const correctness fixes from attachment 141364.
    Suggestions that require code change beyond function signature are postponed to a further batch.
  * Fix for "C++ importer does not recognize 'noexcept' keyword" : (kde#442134)
  * Const correctness fixes addressing roughly the first half of attachment 141364.
    Changes that did not succeed offhand are postponed to a second batch.
* Tue Nov  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.3/
- No code change since 21.08.2
* Tue Oct  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.2/
- No code change since 21.08.1
* Wed Sep  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.1
- No code change since 21.08.0
* Thu Aug 26 2021 Christophe Giboudeaux <christophe@krop.fr>
- Remove the kdevelop build dependencies for archs missing
  qtwebengine.
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.0
- No code change since 21.07.90
* Fri Jul 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.90
  * New feature release
- No code change since 21.07.80
* Sat Jul 17 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.80
  * New feature release
- Changes since 21.04.3:
  * Fix user visible copyright string (no SPDX) (2)
  * Fix user visible copyright string (no SPDX)
  * cmake ignored MSVC , lets try NOT WIN32
  * Disable LLVM tests temporarly for MSVC systems for the sake of CI Builds
  * Revert changes to heading templates
  * Manual conversions & formatting
  * Convert copyright texts to SPDX format
  * Fix formatting for SPDX headers
  * Convert license headers to SPDX
  * lib/cppparser/lexer.cpp : In function tokenize() replace
    `for (;;)` by `while (!eof())`.
  * lib/cppparser/lexer.h : In functions offset(int) and
    getOffset(const QChar*) add Q_ASSERT calls to expose invalid
    inputs at their source.
  * codeimpwizard/codeimpthread.cpp : In CodeImpThread(QFileInfo&, QObject*)
    call to connect() fix signature of SIGNAL(askQuestion) and SLOT(questionAsked).
- Only install the license files once
* Wed Jul  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.3
- No code change since 21.04.2
* Mon Jun 28 2021 Christophe Giboudeaux <christophe@krop.fr>
- Add patch to get rid of the QtWebKit dependency:
  * 0001-Make-QtWebKit-usage-in-WelcomePage-optional-with-QTe.patch
* Tue Jun  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.2
- Changes since 21.04.1:
  * umbrello/version.h umbrello/main.cpp : Update copyright year.
* Wed May 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/21.04.1
- Changes since 21.04.0:
  * Fix crash related to multiple calls of m_source.unicode()
  * lib/cppparser/lexer.{h,cpp} cosmetics and error detection improvement:
  * lib/cppparser/driver.cpp cosmetics in class Driver::ParseHelper
  * Support C++11 "enum class" in C++ Import:
  * Compile on Qt4: QStringLiteral -> QLatin1String
  * test/import/cxx/namespace-enum-literal.h : Document semicolon after end of namespace.
  * test/import/cxx/comments-class-enums.h: Fix typo in comment, add newline at EOF.
* Fri Apr 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04
- No code change since 21.03.90
- Stop owning directories provided by the filesystem package (boo#1184786)
* Fri Apr  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.90
  * New feature release
- No code change since 21.03.80
* Sun Mar 21 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.80
  * New feature release
- Too many changes since 20.12.3, only listing bugfixes:
  * codegenerators: python: Do not create files for classes that has containers (kde#432854)
  * Fix 'Not all Umbrello global settings are saved to the resource file' (kde#430720)
  * Address 'It shall be possible to nest folders in packages' : (kde#430593)
  * Fix for 'Nested folders are not loaded properly' (kde#430323)
  * Fix for 'Crash on exit with tabbed diagrams enabled' (kde#430322)
  * umbrello/version.h - Increase XMI_FILE_VERSION to 1.7.0 to reflect major change in XMI attribute order. (kde#363582)
  * Fix for 'Callback message in sequence diagram cannot be resized' (kde#429794)
* Thu Mar  4 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/20.12.3
- No code change since 20.12.2
* Wed Feb  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-02-apps-update
- Changes since 20.12.1:
  * umbrello/umlscene.cpp: Fix crash on exit with widget selected in diagram
- Add a _constraints file to avoid disk space failures.
* Tue Jan  5 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-01-apps-update
- No code change since 20.12.0
* Sat Dec  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-12-apps-update
- No code change since 20.11.90
* Fri Nov 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.90
  * New feature release
- No code change since 20.11.80
* Sat Nov 14 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.80
  * New feature release
- Too many changes since 20.08.3, only listing bugfixes:
  * Add support to use external KDevPHP packaga (kde#428460)
* Thu Nov  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-11-apps-update
- Changes since 20.08.2:
  * cmake: Add fallback in case QTQCHDIR was not found for KF5 build variant
  * Fix "file cannot create directory: /qch. Maybe need administrative privileges" (kde#427070)
  * Add cmake command line option BUILD_QCH to support building without QCH support if requested
* Fri Oct  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-10-apps-update
- No code change since 20.08.1
* Tue Sep  1 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-09-apps-update
- Changes since 20.08.0:
  * Compile fix
  * Fix 'No display of foreign key constraints when opening a file' (kde#425285)
  * Fix 'Double association in the diagram after renaming a foreign key constraint' (kde#425281)
* Sun Aug  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-08-apps-update
- Changes since 20.07.90:
  * New feature allowing word wrapping in use case texts
    when resizing and entering line breaks (kde#424863)
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.90
  * New feature release
- Changes since 20.07.80:
  * cmake: fix umbrello version
  * cmake: Fix build issue with kdevelop 5.2.1 on Ubuntu 18.04 (kde#424794)
* Sun Jul 19 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.80
  * New feature release
- Changes since 20.04.3:
  * release-windows-packages: add command line options --tarversion to specify different tar ball version
  * release-windows-packages: add command for updating obs package
  * release-windows-package: add variable for running osc
  * tab 2 spaces
  * Fix compiler warning
  * Coverity check CID 268401: Copy into fixed size buffer (STRING_OVERFLOW)
  * Switch to https for bugs.kde.org
* Thu Jul  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-07-apps-update
- Changes since 20.04.2:
  * Fix 'Class Diagram Widget Text Truncated Upon Re-Opening XMI' on Windows 10 (kde#423660)
* Tue Jun  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-06-apps-update
- Changes since 20.04.1:
  * Address https://bugs.kde.org/show_bug.cgi?id=56184#c94
  * Fix 'Umbrello code importer does not import c++ header file wrapped with __cplusplus macro' (kde#422356)
* Fri May 15 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-05-apps-update
- Changes since 20.04.0:
  * Fixes for adding multiline c++ comment support (kde#418970)
  * Remove independent comments from list in CommentStore::getCommentsInRange()
  * Initial work for combining multi line c++ comments
  * Extend test case for class comments with c++ style and doxygen comments
  * Add documentation to class Driver
* Thu Apr 23 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-04-apps-update
- Changes since 20.03.90:
  * cmake: fix version compare lower syntax
  * unittests: fix checking llvm version number
  * cmake: fix minor version
  * unittests: only build llvm testcase with the supported versions 7 and 8
  * cmake: Remove limits for generating dot graphs
  * cmake use svg as image format for dot
  * cmake: increase maximum dot graph depth to not limit generated graphs
  * cmake: on generating api doc disable using multiple dot targets
  * cmake: Only enable generating dot files if the 'dot' tool was found
  * Add support for Qt5 variant of qhelpgenerator
* Sun Apr  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.90
  * New feature release
- Changes since 20.03.80:
  * Fixed cmake 3.10 error caused by not setting policy CMP0057 to NEW
  * Fix bug not building apidoc and qch file by default, if enabled (kde#419202)
* Sun Mar 22 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.80
  * New feature release
- Too many changes to list here.
* Thu Mar  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-03-apps-update
- Changes since 19.12.2:
  * Use the global xml catalog to replace external docbook.xsl uri
  * Use a more reliable way on Windows to find the application's installation root
  * Fix finding docbook stylesheet by using xml catalog support
  * Fixed error message 'Can't save an empty diagram' with Docbook and Xhtml export (kde#417784)
  * Correction of the path setting for the Docbook and Xhtml export
  * Fix KF5 issue 'Exporter searches for XSLT file in nonexistent directory' (kde#417520)
  * Fix '404 on help for settings in Umbrello (kde#410906)
  * cmake: remove annoying suggest-override warning
  * Fix using wrong name for slotInterfaceRequired() in class WorkToolBar
* Fri Feb  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Wed Feb  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-02-apps-update
- Too many changes since 19.12.1, only listing bugfixes:
  * Improve creation of generalization with parent provided as string: (kde#416178)
  * Fix broken file selection for PHP and SQL in code import wizard: (kde#335566)
  * Fix endless loop on importing mysql schema: (kde#398082)
  * Fix 'Missing entries in the New context menu entry for the logical view' (kde#416053)
  * Fix 'Umbrello Crash On Moving the Seconds element in the Class Diagram' (kde#416013)
  * Fix 'No association update after changing a class attribute type from class to class pointer or address and vice versa' (kde#416006)
  * Fix 'Duplicate Composition Association when rename it's variable in the tree View' (kde#415992)
* Tue Jan  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12.1
- Changes since 19.12.0:
  * Remove obsolete code
  * Fix 'No undo support for adding connected widgets' (kde#415888)
  * Fix 'Different name when adding connected states compared to adding via the toolbar' (kde#415890)
  * Fix 'Adding connected widgets cannot be cancelled' (kde#415889)
  * Limit building local KDev::Tests library for KF5 only when kdevplatform library has been found
  * Library KDev::Tests: remove Qt5::Tests dependencies (kde#415849)
  * Embed KDev::Tests library to not depend on kdevplatform for KF5 builds
  * Fix 'The initial cursor position in the properties dialog of a state should be set to the name field' (kde#415784)
  * Fix 'Adding a connected state should allow entering of a state name' (kde#415779)
* Tue Dec 10 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12
- Changes since 19.11.90:
  * Fix api issue in class ToolBarState in case UMLScene is constructed without a view
  * Add save/load unit test for class PreConditionWidget
  * Fix 'Sequence diagram - on reload file - app crash when conditions are added' (kde#414759)
  * Apply quick fix to prevent crashing on loading extented testcase for reproducing behaviour
  * Handle "show property dialog" content menu entry for combined fragment and precondition widgets
  * Fix 'Missing property dialog entries in context menu for combined fragment and precondition widgets' (kde#414778)
* Sat Nov 30 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/19.12-rc
- Too many changes since 19.11.80, only listing bugfixes:
  * Fix 'Crash on pasting a sequence diagram elements' (kde#414615)
  * Fix 'No namespace creation when importing stack traces' (kde#414599)
  * Fix 'Incorrect applying of an auto layout for spline line type' (kde#414568)
  * Fix 'No control points are created for association lines in "spline"
    layout default mode' (kde#414520)
  * Fix 'Associations are sometime not addable in class diagram' (kde#409631)
  * Fix of string includes in c++ code generator (kde#413569)
* Sun Nov 24 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.80
  * New feature release
- Too many changes since 19.08.3, listing only bugfixes:
  * Fix 'Classifier unit case not enabled' (kde#414044)
  * Fix 'auto-generated getters and setters to atributes are private in generated java classes' (kde#331655)
  * Add customizable class variable prefix for c++ code generation (kde#57583)
  * Add additional c++ code generation policies to fix unexpected code generation (kde#413991)
  * Fix 'Added points to an association do not display them by default' (kde#413910)
  * Fix 'For relationships, partially unsupported properties are displayed in the properties dialog on the style page' (kde#413908)
  * Fix 'Changes to the fill color of the head of a composition are not displayed' (kde#413907)
  * Implement 'Open file assigned to an artifact' (kde#410937)
  * Add support for adding connected "required interfaces" (kde#403794)
  * Add subsystem support to toolbar and context menu for component diagrams (kde#410543)
  * Fix 'Incorrect icon in toolbar for adding interfaces to component diagram' (kde#410519)
  * Add missing context menu entries for activity diagrams (kde#410479)
* Thu Nov  7 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.3.php
- Changes since 19.08.2:
  * Cleanup of generated c++ code (kde#413574)
  * cppwriter: In case of interfaces, do not write a superfluous .cpp file
  * When creating class methods for an interface through the user interface set abstract and virtual attributes (kde#413519)
  * Fixes missing initialisation of members m_inline and m_abstract of class UMLOperation
  * Disable unrelated checkboxes in operation property dialog for interfaces
  * cppwriter: Add support for writing abstract methods
* Fri Oct 11 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.2.php
- No code change since 19.08.1
* Thu Sep  5 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.1.php
- Changes since 19.08.0:
  * Fix build with cmake < 3.7
  * Fixed grammer and punctuation
  * Fixup
  * Fix 'Umbrello could not open imported source files' (kde#410904)
* Fri Aug  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.0.php
- Changes since 19.07.90:
  * Activate newly added association rules for UML2 "required interface" (kde#115269)
  * Add UML2 support for "required interface" associations
  * Fix 'Properties dialog box for components does not display links' (kde#410513)
  * Component symbol made more unique by enlarging the inner rectangle
  * Fix icon for UML2 components
  * cmake: make umbrello version number generating more robust
  * Indention fix
  * Fixup of icons for adding states
  * New icon for activities added to toolbar and context menu (kde#410508)
* Tue Aug  6 2019 lbeltrame@kde.org
- Update to 19.07.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-rc.php
- Changes since 19.07.80:
  * Too many changes to list here
* Tue Jul 23 2019 lbeltrame@kde.org
- Update to 19.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-beta.php
- Changes since 19.04.3:
  * Too many changes to list here
* Sat Jul 13 2019 lbeltrame@kde.org
- Update to 19.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.3.php
- Changes since 19.04.2:
  * Fix build error in DocBook generator
  * Fix build errors in Python code importer
  * Fix 'Export to XHTML generates empy html file' (kde#409411)
  * cmake 3.5 fix
  * CMake spelling fix
  * Fix cmake error 'cannot parse the expression: " + 1"'
  * Move negative sign handling into PythonImport::parseInitializer()
  * Add constructor visibility test to python test cases
  * python importer: Extend for parsing method parameter default values (kde#409210)
  * Fix 'Python import do not support attributes with initializers' (kde#409209)
  * Fix 'Umbrello wont create a UML diagram relation between two objects' (kde#409161)
* Fri Jun  7 2019 lbeltrame@kde.org
- Update to 19.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.2.php
- No code changes since 19.04.1
* Fri May 10 2019 lbeltrame@kde.org
- Update to 19.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.1.php
- Changes since 19.04.0:
  * file import: do not use overwritten temporary file (kde#406574)
* Sat Apr 20 2019 lbeltrame@kde.org
- Update to 19.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.0.php
- No code changes since 19.03.90
* Tue Apr  9 2019 lbeltrame@kde.org
- Update to 19.03.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-rc.php
- Changes since 19.03.80:
  * Fix Qt5 compiling with kdevplatform version 5.3.2
  * Fix Qt5 compile
  * Fix removing slashes in path in case single files are imported
  * Fix crash on accessing zero pointer on importing src code (kde#405535)
  * Reduce difference between build variants
  * Move KDE4 specific ecm wrapper macros into a separate macro file
  * Add class InterfaceWidget
* Wed Mar 27 2019 lbeltrame@kde.org
- Update to 19.03.80
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-beta.php
- Changes since 18.12.3:
  * Fix minor EBN issues
* Sat Mar  9 2019 lbeltrame@kde.org
- Update to 18.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.3.php
- Changes since 18.12.2:
  * Fix 'No tree view update of entity unique and check constraint'
  * Fix moving entities by property dialog
  * Fix 'Cannot move entities, components, subsystems and nodes from sub folder to root folder' (kde#404892)
  * Fix allowing moving of ports to a sub folder in the tree view
  * Fix 'No tree view update of entity primary key constraint' (kde#350241)
  * Add typedef to class UMLForeignKeyConstraintDialog
  * Fix 'Cannot add foreign key to entity' (kde#404891)
  * release-windows-packages: auto detect version
  * release-windows-packages: fix fetching source tar ball name
  * Fix 'Non-optimal vertical position of added messages to sequence diagrams' (kde#404422)
  * Handle default case in ChildWidgetPlacementPort::setNewPositionWhenMoved
  * Fix crash on adding ports to component widget by context menu
* Sat Feb  9 2019 lbeltrame@kde.org
- Update to 18.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.2.php
- Changes since 18.12.1:
  * Compile fix
  * Fix 'Duplicated text labels in xmi file' (kde#403888)
  * Fix 'Copy and paste of interface in component diagram does not update the displayed name' (kde#403853)
  * Fix 'Displayed interface name in the component diagram is not updated after changing it in the properties dialog' (kde#403852)
  * In AssociationWidget::widgetMoved() fix endless loop
  * Add test file for component diagram elements and associations
  * Fix 'Displayed name of an interface in a component diagram is not updated' (kde#403763)
  * Fixes the problem that the geometry of the interface widget was not updated when the connection was disconnected
  * Fix 'incorrect display of interface widgets in the component diagram when adding a second connection' (kde#403761)
  * In UMLWidget::mouseMoveEvent() remove duplicated call to adjustUnselectedAssocs()
  * Fix 'Associations connected to the component port do not move when moving the component' (kde#403692)
  * Fix unused parameter warning
  * On loading port widgets from xmi file setup connected state
  * Do not add building tests unconditional
  * Fix 'Incorrect port positions when loading old files' (kde#403622)
  * Make sure to only remove present ports
  * Use a better location for deleting UML Port instance
  * Fix 'Port widgets cannot be deleted from the context menu' (kde#403618)
  * Add "show" and "properties" to context menu of tree view item types 'category' and 'artifact'
  * Add missing "show" in diagram context menu entry to tree view items
  * When deleting port widgets, also delete the corresponding UML port (kde#403515)
  * Fix center position for showing port widgets
  * Add missing port widgets when loading component diagrams
  * Fix minor Doxygen issues
* Fri Jan 11 2019 lbeltrame@kde.org
- Update to 18.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.1.php
- Changes since 18.12.0:
  * Fix 'Strange multiple duplication of labels on interfaces in component diagram after saving' (kde#402722)
  * Cleanup owner setting of PinPortBase related classes in constructor
  * In ClassifierWidget fix duplicated common painting in widget interface variant
  * Update docbook files to version 4.5 to be compatible with KF5
* Fri Dec 14 2018 lbeltrame@kde.org
- Update to 18.12.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.0.php
- Changes since 18.11.90:
  * Fix KDE CI compile error with Qt 5.10 on linux
  * Fix -Wimplicit-fallthrough issue
  * Make call to QUrl::adjusted() really working
  * Make call to QString::toLower() really working
  * Make call to QString::simplified() really working
  * Fix output of used Qt version for KF5 builds
* Mon Dec  3 2018 lbeltrame@kde.org
- Update to 18.11.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-rc.php
- Changes since 18.11.80:
  * JavaImport: Convert Java specific notation '...' into a language independent array definition (kde#401290)
  * Fix 'SQL code indexes wrong field for foreign key' (kde#292239)
  * Crash fix in case of exporting an entity relation diagram
  * Fix 'Endless loop on importing mysql schema' (kde#98082)
* Tue Nov 20 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Tue Nov 20 2018 lbeltrame@kde.org
- Update to 18.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-beta.php
- Changes since 18.08.3:
  * Too many changes to list here
* Thu Nov  8 2018 lbeltrame@kde.org
- Update to 18.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.3.php
- Changes since 18.08.2:
  * Fixup of commit af72e05 (kde#400501)
  * Fixes broken docbook URLs when creating xhtml (kde#400657)
  * Make it possible to run docbook export from build dir
  * Fix 'Umbrello fails to start due to ASSERT failure in QVector<T>::at "index out of range"' (kde#400501)
* Thu Oct 11 2018 lbeltrame@kde.org
- Update to 18.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.2.php
- Changes since 18.08.1:
  * Implementation of dragging multiple entries from the tree view and inserting them into the diagram (kde#394606)
  * Fix 'Multiple creation of the same entity on an entity relationship diagram' (kde#399475)
  * Fix 'changes on "entitätattribut" changes the attributes also on an copy' (kde#158647)
  * Refactored UMLDragData::decodeClip4() to use better variable names
* Thu Sep  6 2018 lbeltrame@kde.org
- Update to 18.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.1.php
- Changes since 18.08.0:
  * Adding a C++ test case with multiple template parameters
  * More robust determination of the name of the base class with template parameters using the abstract syntax tree
  * Fix 'C++ importer does not correctly detect generalization in template classes' (kde#397664)
* Thu Aug 16 2018 christophe@krop.fr
- Update to 18.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.0.php
- Changes since 18.07.80:
  * Never implemented context menu entry for adding actor, usecase, component, artifact and activity from a widget
  * Never implemented context menu entry for adding a subsystem port removed
  * Never implemented context menu entry for adding a subsystem removed
  * Remove context menu entry for adding port on component diagrams
  * Fix position of adding note entry to context menu entries
  * Position and presence of adding plain text unified using context menu for diagrams and widgets
  * Fix 'Set input focus on first input field in the general properties dialog page' (kde#396844)
* Thu Jul 26 2018 lbeltrame@kde.org
- Update to 18.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08-beta.php
- Changes since 18.04.3:
  * Too many changes to list here
* Fri Jul 13 2018 lbeltrame@kde.org
- Update to 18.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.3.php
- Changes since 18.04.2:
  * None
* Fri Jun  8 2018 lbeltrame@kde.org
- Update to 18.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.2.php
- Changes since 18.04.1:
  * Fix missing keyboard shortcut for "line with" label in style page
  * Disable deprecated warnings
  * Add <launchable> entry to umbrello appdata xml file CCBUG:391559
  * Fix 'Artifact subdir name includes root path in tree view' on Windows (kde#394446)
* Fri May 11 2018 lbeltrame@kde.org
- Update to 18.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.1.php
- Changes since 18.04.0:
  * Merge in fixes from kmymoney related script variant
  * Add c++ import support for combinations of 'explicit', 'constexp' keywords in combination with constructors (kde#392984)
  * Fix "c++ importer does not recognize 'explicit' keyword" (kde#392984)
* Wed Apr 18 2018 lbeltrame@kde.org
- Update to 18.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.0.php
- Changes since 18.03.90:
  * Fix "c++ importer does not recognize 'explicit' keyword" (kde#392984)
  * Add importing c++ keyword "friend" for class members
* Fri Apr  6 2018 lbeltrame@kde.org
- Update to 18.03.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04-rc.php
- Changes since 17.12.3:
  * Too many changes to list here
* Thu Mar  8 2018 lbeltrame@kde.org
- Update to 17.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.3.php
- Changes since 17.12.2:
  * Fix duplicated adding of floating text widgets to scene on loading an xmi file
  * Fix 'Imported classes from file do not show available associations' (kde#390901)
  * Fixup of 0f09ef6fb
  * Fix 'Notes diagram link could not be changed' (kde#390891)
  * Increase shape part for resize marker to make it easier to select in low zoom levels
  * Fixup shape for alternate combined fragment widget
  * Fix 'Vertical position of combined fragment widget else part is moved to the vertical center after save/load cycle' (kde#390782)
  * Fix 'Loading combined fragments from xmi file adds unwanted else part' (kde#390780)
  * Fix writing out state information in ticket body
  * Fix 'Instable vertical position of alternate combined fragment widget' (kde#390677)
  * Fix 'Box widgets inside a combined fragment are not selectable' (kde#389357)
  * Refactoring of global variables used by class CombinedFragmentWidget
  * Fix 'Not possible to select notes under a fragment widget in sequence diagrams' (kde#390509)
  * Fix 'Could not set fill color for message widgets' (kde#390511)
  * Fix 'No context menu entry for changing colors of a single selected message widget' (kde#390508)
* Wed Feb  7 2018 lbeltrame@kde.org
- Update to 17.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.2.php
- Changes since 17.12.1:
  * Fix writing '44' as true boolean value into xmi file for attributes usesdiagramfillcolor and usesdiagramusefillcolor
  * Reorder 'useDiagram' related variables alphabetical.
  * Fix 'Naming of new datatypes' (kde#389353)
  * Fix 'Font is always bold when model is opened, although default font is regular style' (kde#389357)
  * Fix 'Bug in Source Code Editor'
  * extract messages from umbrelloui.rc.cmake
* Thu Jan 11 2018 lbeltrame@kde.org
- Update to 17.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.1.php
- Changes since 17.12.0:
  * Keep calls to Import_Utils::remapUMLEnum() in Ada, IDL and Pascal import in sync with in java and csharp import
  * Fixup of b4a20d4fb
  * Fix bug not saving "show stereotype" class widget setting to xmi file (kde#388560)
  * Fix 'Cannot start umbrello from applications menu' (kde#388549)
  * Catch configuring KDE4 variant of umbrello with installed KF5 kdevplatform development package
  * Complete java import fix (kde#386479)
  * Spelling fix
  * Fix 'Imported classes are not placeable on diagrams after java import' (kde#386479)
  * Fix implementation of Import_Utils::createUMLObject() parameter searchInParentPackageOnly
  * Add additional java test files
  * Fix 'umbrello5 does not display any files using default file pattern' (kde#388171)
  * Fix 'Umbrello 2.2.3 crashes when deleting three text labels' (kde#387939)
  * Remove faulty '\n'
  * Fix 'Broken link to omg.org/spec in "About->Umbrello" dialog' (kde#387912)
  * fix autoscroll for Logger
* Sat Dec  9 2017 lbeltrame@kde.org
- Update to 17.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.0.php
- Changes since 17.11.90:
  * None
* Sat Dec  2 2017 lbeltrame@kde.org
- Update to 17.11.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-rc.php
- Changes since 17.11.80:
  * There's no need to include the version into the desktop file
  * Fix layouts path in dot generator on Qt5
* Mon Nov 20 2017 lbeltrame@kde.org
- Update to 17.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-beta.php
- Changes since 17.08.3:
  * Too many changes to list here
* Thu Nov  9 2017 lbeltrame@kde.org
- Update to 17.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.3.php
- Changes since 17.08.2:
  * None
* Mon Oct 16 2017 lbeltrame@kde.org
- Update to 17.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.2.php
- Changes since 17.08.1:
  * Potiental crash fix
* Fri Sep  8 2017 jengelh@inai.de
- Remove unnecessary ldconfig call, there are no shared libraries
  in here.
* Thu Sep  7 2017 lbeltrame@kde.org
- Update to 17.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.1.php
- Changes since 17.08.0:
  * Potiental crash fix
  * Fix partially hidden content in code importer options page
  * Add macros to install translated artifacts for KF5
  * More memory leak fixes
  * Fix possible memory leak
  * Remove duplicate usage of deleting graphics scene items
  * Fix 'Crash in component diagram after deleting component' (kde#383592)
  * Fix memory leaks
  * Fix 'Tree view is not visible after import' (kde#383618)
  * Fix 'c++ methods are not imported if class is defined outside name space' (kde#383445)
  * Move implementation of isCaseSensitive() and scopeSeparator() to Uml::ProgrammingLanguage namespace
  * Add class member m_doc to CppTree2Uml and use it instead of the long pointer hierachy
* Fri Aug 11 2017 christophe@krop.fr
- Update to KDE Applications 17.08.0
  * New feature release
  * https://www.kde.org/announcements/announce-applications-17.08.0.php
- Changes since 17.04.3 :
- Too many changes to list here
* Sat Aug  5 2017 christophe@krop.fr
- Update to KDE Applications 17.07.90
  * KDE Applications 17.07.90
  * https://www.kde.org/announcements/announce-applications-17.08-rc.php
* Sun Jul 16 2017 lbeltrame@kde.org
- Update to 17.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.3.php
- Changes since 17.04.2:
  * Fix crash on importing sequence lines from qt creator.
  * Make bounding box debug display of class UMLWidget visible with default border colors.
  * Fix 'class diagram: class-box not resizable'. (kde#381730)
  * Fixup of 'org.kde.umbrello5.desktop has wrong Exec line'. (kde#381565)
  * Fix 'org.kde.umbrello5.desktop has wrong Exec line'. (kde#381565)
  * Fix 'Documentation widgets in property dialogs have a border margin'. (kde#381393)
  * Fix 'Documentation window does not show the correct icon'. (kde#381363)
  * Fix 'Documentation window does not show the correct icon'. (kde#381363)
  * Fix 'Documentation window does not show doc for association widgets with non empty name'. (kde#381360)
  * Fix 'Association documentation not shown in Documentation panel'. (kde#381016)
* Fri Jun 23 2017 wbauer@tmo.at
- Fix the desktop file's Exec line, the executable is named
  umbrello5 (boo#1045654)
* Wed Jun  7 2017 lbeltrame@kde.org
- Update to 17.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.2.php
- Changes since 17.04.1:
  * Fix 'Building Umbrello 2.21.90.89e79b8 with optional LLVM fails'. (kde#379293)
  * Fix 'umbrello/KF5 does not show the KF5 crash dialog'. (kde#374415)
  * Add some error message to debug output in case of file saving fails.
* Wed May 17 2017 lbeltrame@kde.org
- Update to 17.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.1.php
- Changes since 17.04.0:
  * Fix coverity CID 88358: Unchecked dynamic_cast
  * Fix coverity CID 88359: Unchecked dynamic_cast
  * Fix coverity CID 88360: Unchecked dynamic_cast
  * Fix coverity CID 88361: Unchecked dynamic_cast
  * Fix coverity CID 88362: Unchecked dynamic_cast
  * Fix coverity CID 88363: Unchecked dynamic_cast
  * Fix coverity CID 88364: Unchecked dynamic_cast
  * Fix coverity CID 88416: Dereference before null check
  * Fix coverity CID 88428: Dereference before null check
  * Fix coverity CID 88471: Dereference before null check
  * Fix coverity CID 178697: Dereference after null check
  * Fix coverity CID 178698: Unchecked dynamic_cast
  * Fix coverity CID 178700: Missing break in switch
  * Fix coverity CID 178701: Dereference null return value
  * Let debug package build fail if no version has been found.
  * Fix osc project path.
* Sun Apr 16 2017 lbeltrame@kde.org
- Update to 17.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.0.php
- Changes since 17.03.90:
  * Fix crash on importing empty lines.
* Wed Apr 12 2017 lbeltrame@kde.org
- Update to 17.03.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-rc.php
- Changes since 17.03.80:
  * release-windows-packages: Do not create ticket with 'all' command
  * release-windows-packages: pack debug package with 'all' command
  * Fix 'org.kde.umbrello.appdata.xml specifies wrong binary name'.
  * Fix 'KF5 version fails to install'.
- Remove patches, now upstream:
  * fix-appstream-install-1.patch
  * fix-appstream-install-2.patch
* Sat Mar 25 2017 lbeltrame@kde.org
- Update to 17.03.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-beta.php
- Changes since 16.12.3:
  * Too many changes to list here
- Add upstream patches to fix build:
  * fix-appstream-install-1.patch
  * fix-appstream-install-2.patch
* Thu Mar  9 2017 lbeltrame@kde.org
- Update to 16.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-16.12.3.php
- Changes since 16.12.2:
  * Fix crash by disconnecting slots in UMLApp::~UMLApp().
* Thu Feb  9 2017 lbeltrame@kde.org
- Update to KDE Applications 16.12.2
  * KDE Applications 16.12.2
  * https://www.kde.org/announcements/announce-applications-16.12.2.php
* Sat Jan 14 2017 lbeltrame@kde.org
- - Update to KDE Applications 16.12.1
  * KDE Applications 16.12.1
  * https://www.kde.org/announcements/announce-applications-16.12.1.php
* Tue Dec 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.12.0
  * KDE Applications 16.12.0
  * https://www.kde.org/announcements/announce-applications-16.12.0.php
* Sat Dec  3 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.90
  * KDE Applications 16.12.0 RC
  * https://www.kde.org/announcements/announce-applications-16.12-rc.php
* Tue Nov 29 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.80
  * KDE Applications 16.12.0 Beta
  * https://www.kde.org/announcements/announce-applications-16.12-beta.php
* Wed Nov  9 2016 lbeltrame@kde.org
- Update to KDE Applications 16.08.3
  * KDE Applications 16.08.3
  * https://www.kde.org/announcements/announce-applications-16.08.3.php
* Tue Oct 11 2016 lbeltrame@kde.org
- KDE Applications 16.08.2
  https://www.kde.org/announcements/announce-applications-16.08.2.php
* Fri Sep  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.1
  * KDE Applications 16.08.1
  * https://www.kde.org/announcements/announce-applications-16.08.1.php
* Fri Aug 12 2016 wbauer@tmo.at
- Don't rename the icon files any more, this breaks the build as
  they are not found
* Fri Aug 12 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.0
  * KDE Applications 16.08.0
  * https://www.kde.org/announcements/announce-applications-16.08.0.php
* Mon Aug  8 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.07.90
  * KDE Applications 16.07.90 (16.08-RC)
  * https://www.kde.org/announcements/announce-applications-16.08-rc.php
* Fri Jul  8 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.3
  * KDE Applications 16.04.3
  * https://www.kde.org/announcements/announce-applications-16.04.3.php
* Fri Jun 10 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.2
  * KDE Applications 16.04.2
  * https://www.kde.org/announcements/announce-applications-16.04.2.php
* Sat May  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.1
  * KDE Applications 16.04.1
  * https://www.kde.org/announcements/announce-applications-16.04.1.php
* Sun Apr 17 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.0
  * KDE Applications 16.04.0
  * https://www.kde.org/announcements/announce-applications-16.04.0.php
* Mon Apr 11 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.03.90
  * KDE Applications 16.04.0 RC
  * https://www.kde.org/announcements/announce-applications-16.04-rc.php
* Sun Mar 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.3
  * KDE Applications 15.12.3
  * https://www.kde.org/announcements/announce-applications-15.12.3.php
  * boo#970855
* Sat Feb 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.2
  * KDE Applications 15.12.2
  * https://www.kde.org/announcements/announce-applications-15.12.2.php
  * boo#966605
* Sat Jan  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.1
  * KDE Applications 15.12.1
  * https://www.kde.org/announcements/announce-applications-15.12.1.php
  * boo#961265
* Sun Dec 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.0
  * KDE Applications 15.12.0
  * https://www.kde.org/announcements/announce-applications-15.12.0.php
  * boo#958887
* Tue Nov 10 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.3
  * KDE Applications 15.08.3
  * https://www.kde.org/announcements/announce-applications-15.08.3.php
  * boo#954531
* Sun Oct 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.2
  * KDE Applications 15.08.2
  * https://www.kde.org/announcements/announce-applications-15.08.2.php
* Sun Sep 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.1
  * KDE Applications 15.08.1
  * https://www.kde.org/announcements/announce-applications-15.08.1.php
* Wed Aug 19 2015 cgiboudeaux@gmx.com
- Update to KDE Applications 15.08.0
  * KDE Applications 15.08.0
  * https://www.kde.org/announcements/announce-applications-15.08.0.php
* Fri Aug  7 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.07.90
  * KDE Applications 15.08.0 RC1
  * https://www.kde.org/announcements/announce-applications-15.08-rc.php
* Mon Jul  6 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.3
  * KDE Applications 15.04.3
  * https://www.kde.org/announcements/announce-applications-15.04.3.php
* Sat May 30 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.2
  * KDE Applications 15.04.2
  * https://www.kde.org/announcements/announce-applications-15.04.2.php
* Mon May 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.1
  * KDE Applications 15.04.1
  * https://www.kde.org/announcements/announce-applications-15.04.1.php
* Sat Apr 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.0
  * KDE Applications 15.04.0
  * https://www.kde.org/announcements/announce-applications-15.04.0.php
* Sat Mar 21 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.03.95
  * KDE Applications 15.04 RC
* Sun Mar  8 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.03.80
  * KDE Applications 15.04 Beta
* Tue Mar  3 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.3
  * KDE Applications 14.12.3
  * See https://www.kde.org/announcements/announce-applications-14.12.3.php
* Sun Feb  1 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.2
  * KDE Applications 14.12.2
  * See https://www.kde.org/announcements/announce-applications-14.12.2.php
* Mon Jan 12 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.1
  * KDE Applications 14.12.1
  * See https://www.kde.org/announcements/announce-applications-14.12.1.php
* Wed Dec 17 2014 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.0
  * KDE Applications 14.12.0
  * See https://www.kde.org/announcements/announce-applications-14.12.0.php
* Sun Nov  9 2014 tittiatcoke@gmail.com
- Update to 4.14.3
  * KDE 4.14.3 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.3.php
* Sun Oct 12 2014 tittiatcoke@gmail.com
- Update to 4.14.2
  * KDE 4.14.2 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.2.php
* Sat Sep 13 2014 tittiatcoke@gmail.com
- Update to 4.14.1
  * KDE 4.14.1 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.1.php
* Fri Aug 15 2014 tittiatcoke@gmail.com
- Update to 4.14.0
  * KDE 4.14.0 SC Final Release
  * See http://www.kde.org/announcements/4.14/
* Thu Jul 17 2014 cgiboudeaux@gmx.com
- Update to 4.13.90
  * KDE 4.14 Beta 2 release
  * See http://www.kde.org/announcements/announce-4.14-beta2.php
* Thu Jul 10 2014 cgiboudeaux@gmx.com
- Update to 4.13.80
  * KDE 4.14 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.14-beta1.php
* Sun Jun  8 2014 tittiatcoke@gmail.com
- Update to 4.13.2
  * KDE 4.13  release
  * See http://www.kde.org/announcements/announce-4.13.2.php
* Fri May  9 2014 tittiatcoke@gmail.com
- Update to 4.13.1
  * KDE 4.13.1  bug fix release
  * See http://www.kde.org/announcements/announce-4.13.1.php
* Sat May  3 2014 hrvoje.senjan@gmail.com
- Added libxml2-devel and libxslt-devel BuildRequires (they where
  pulled in via libkde4-devel previously)
- Remove boost-devel and subversion-devel, not needed
* Fri Apr 11 2014 tittiatcoke@gmail.com
- Update to 4.13.0
  * KDE 4.13  release
  * See http://www.kde.org/announcements/4.13/
* Thu Mar 27 2014 tittiatcoke@gmail.com
- Update to 4.12.97
  * KDE 4.13 RC  release
  * See http://www.kde.org/announcements/announce-4.13-rc.php
* Thu Mar 20 2014 tittiatcoke@gmail.com
- Update to 4.12.95
  * KDE 4.13 Beta 3  release
  * See http://www.kde.org/announcements/announce-4.13-beta3.php
* Thu Mar 13 2014 tittiatcoke@gmail.com
- Update to 4.12.90
  * KDE 4.13 Beta 2  release
  * See http://www.kde.org/announcements/announce-4.13-beta2.php
* Fri Mar  7 2014 tittiatcoke@gmail.com
- Update to 4.12.80
  * KDE 4.13 Beta 1  release
  * See http://www.kde.org/announcements/announce-4.13-beta1.php
* Sat Feb  1 2014 tittiatcoke@gmail.com
- Update to 4.12.2
  * KDE 4.12.2  release
  * See http://www.kde.org/announcements/announce-4.12.2.php
* Sat Jan 11 2014 tittiatcoke@gmail.com
- Update to 4.12.1
  * KDE 4.12.1  release
  * See http://www.kde.org/announcements/announce-4.12.1.php
* Sat Dec 14 2013 tittiatcoke@gmail.com
- Update to 4.12.0
  * KDE 4.12.0  release
  * See http://www.kde.org/announcements/4.12.php
* Fri Nov 29 2013 tittiatcoke@gmail.com
- Update to 4.11.97
  * KDE 4.12 RC 1 release
  * See http://www.kde.org/announcements/announce-4.12-rc.php
* Sat Nov 23 2013 tittiatcoke@gmail.com
- Update to 4.11.95
  * KDE 4.12 Beta 3 release
  * See http://www.kde.org/announcements/announce-4.12-beta3.php
* Sat Nov 16 2013 tittiatcoke@gmail.com
- Update to 4.11.90
  * KDE 4.12 Beta 2 release
  * See http://www.kde.org/announcements/announce-4.12-beta2.php
* Sun Nov 10 2013 tittiatcoke@gmail.com
- Update to 4.11.80
  * KDE 4.12 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.12-beta1.php
* Sat Nov  2 2013 tittiatcoke@gmail.com
- Update to 4.11.3
  * KDE 4.11.3 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.3.php
* Sat Sep 28 2013 tittiatcoke@gmail.com
- Update to 4.11.2
  * KDE 4.11.2 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.2.php
* Sun Sep  1 2013 tittiatcoke@gmail.com
- Update to 4.11.1
  * KDE 4.11.1 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.1.php
* Thu Aug  8 2013 tittiatcoke@gmail.com
- Update to 4.11.0
  * KDE 4.11 Final release
  * See http://www.kde.org/announcements/4.11/
* Thu Jul 25 2013 hrvoje.senjan@gmail.com
- Update to 4.10.97
  * KDE 4.11 RC 2 release
  * See http://www.kde.org/announcements/announce-4.11-rc2.php
* Mon Jul 15 2013 cgiboudeaux@gmx.com
- Update to 4.10.95
  * KDE 4.11 RC 1 release
  * See http://www.kde.org/announcements/announce-4.11-rc1.php
* Wed Jul  3 2013 tittiatcoke@gmail.com
- Update to 4.10.90
  * KDE 4.11 Beta 2 release
  * See http://www.kde.org/announcements/announce-4.11-beta2.php
* Thu Jun 13 2013 tittiatcoke@gmail.com
- Update to 4.10.80
  * KDE 4.11 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.11-beta1.php
  * Split off from kdesdk4
* Sat Jun  1 2013 tittiatcoke@gmail.com
- Update to 4.10.4
  * Bugfix release
  * See http://www.kde.org/announcements/announce-4.10.4.php
  * resolves bnc#8122760
* Sat May  4 2013 tittiatcoke@gmail.com
- Update to 4.10.3
  * Bugfix release
  * See http://www.kde.org/announcements/announce-4.10.3.php
  * resolves bnc#818500
* Fri Apr 12 2013 tittiatcoke@gmail.com
- Updated Licenses for the packages (bnc#814081)
* Mon Apr  1 2013 tittiatcoke@gmail.com
- Update to 4.10.2 \n  * Bugfixes
* Sat Mar  2 2013 tittiatcoke@gmail.com
- Update to 4.10.1
  * Contains bug fixes. See http://www.kde.org/announcements/
  for more information
* Thu Jan 31 2013 tittiatcoke@gmail.com
- Update to 4.10.0
  * This is the final release for 4.10. Contains bugfixes
* Thu Jan 17 2013 tittiatcoke@gmail.com
- Update to 4.9.98
  * This is the third RC release for 4.10. Contains bugfixes
* Thu Jan  3 2013 tittiatcoke@gmail.com
- Update to 4.9.97
  * This is the second RC release for 4.10. Contains bugfixes
* Wed Dec 19 2012 tittiatcoke@gmail.com
- Update to 4.9.95
  * This is the first RC release for 4.10. Contains bugfixes
* Sat Dec  1 2012 tittiatcoke@gmail.com
- Update to 4.9.90
  * This is the second Beta release for 4.10. Contains bugfixes
* Sat Nov 24 2012 tittiatcoke@gmail.com
- Update to 4.9.80
  * see http://www.kde.org/announcements/announce-4.10-beta1.php
  * Umbrello:  Line based diagram grid
* Fri Nov  2 2012 tittiatcoke@gmail.com
- Update to 4.9.3
  * see http://kde.org/announcements/announce-4.9.3.php for details
* Sat Sep 29 2012 tittiatcoke@gmail.com
- Update to 4.9.2
  * see http://kde.org/announcements/announce-4.9.2.php for details
* Wed Sep  5 2012 dmueller@suse.com
- update to 4.9.1
  * see http://kde.org/announcements/4.9.1/ for details
* Sat Aug  4 2012 ctrippe@opensuse.org
- fix lokalize issue with startup with project file (bnc#774072,
  kde#300810)
* Mon Jul 30 2012 dmueller@suse.com
- update to 4.8.5
  * see http://kde.org/announcements/changelogs/changelog4_8_4to4_8_5.php for details
* Fri Jun  1 2012 dmueller@suse.com
- update to 4.8.4
  * see http://kde.org/announcements/changelogs/changelog4_8_3to4_8_4.php for details
* Sun Apr 29 2012 dmueller@suse.com
- update to 4.8.3
  * see http://kde.org/announcements/changelogs/changelog4_8_2to4_8_3.php for details
* Mon Apr  9 2012 ctrippe@opensuse.org
- lokalize requires kross-python for scripts (bnc#754576)
* Sun Apr  1 2012 wstephenson@suse.com
- Fix broken permissions problem in script
* Sat Mar 31 2012 wstephenson@suse.com
- Add xz to BuildRequires
* Thu Mar 29 2012 dmueller@suse.de
- update to 4.8.2
  * see http://kde.org/announcements/changelogs/changelog4_8_1to4_8_2.php for details
* Fri Mar  2 2012 dmueller@suse.de
- update to 4.8.1
  * see http://kde.org/announcements/changelogs/changelog4_8_0to4_8_1.php for details
* Fri Jan 27 2012 tchvatal@suse.cz
- Add patch for lokalize fixing upstream bug #292575
* Wed Jan 18 2012 dmueller@suse.de
- update to 4.8.0
  * first stable release of KDE 4.8 (only critical fixes over 4.7.98)
  * see http://kde.org/announcements/4.8/ for details
* Tue Jan 10 2012 dmueller@suse.de
- update to 4.7.98
  * RC2+ milestone release of KDE 4.8
  * see http://kde.org/announcements/4.8/ for details
* Wed Dec  7 2011 coolo@suse.com
- fix license to be in spdx.org format
* Sat Dec  3 2011 rwooninck@opensuse.org
- Add libtool as BuildRequires to build kstartperf
* Fri Dec  2 2011 dmueller@suse.de
- update to 4.7.4
  * see http://kde.org/announcements/changelogs/changelog4_7_3to4_7_4.php for details
* Wed Nov 30 2011 idoenmez@suse.de
- Fix build with Qt 4.8
* Wed Nov  2 2011 dmueller@suse.de
- update to 4.7.3
  * see http://kde.org/announcements/changelogs/changelog4_7_2to4_7_3.php for details
* Fri Oct  7 2011 coolo@suse.com
- buildrequire specific kdelibs4
* Sun Oct  2 2011 dmueller@suse.de
- update to 4.7.2
  * see http://kde.org/announcements/changelogs/changelog4_7_1to4_7_2.php for details
* Fri Sep 23 2011 idonmez@suse.com
- lokalize should depend on kdesdk4-strigi now that kdesdk4 base
  package is gone.
* Sat Sep 17 2011 toddrme2178@gmail.com
- Split kompare-devel package (fix for RPMLINT warning)
- Split kprofilemethod package  (fix for RPMLINT warning)
- Split strigi package  (fix for RPMLINT warning)
- Fixed kde4-l10n-devel group (fix for RPMLINT warning)
- Capitalized dolphin-plugins summary (fix for RPMLINT warning)
- Fixed okteta self-obsoletes (fix for RPMLINT warning)
- Removed duplicate files (fix for RPMLINT warning)
- Removed empty base package  (fix for RPMLINT warning)
- Added base package obsoletes/provides to strigi package
- Cleaned up spec file formatting
* Thu Sep  8 2011 andrea.turrini@gmail.com
- fixed typos in descriptions of kdesdk4.spec
* Fri Sep  2 2011 dmueller@suse.de
- update to 4.7.1
  * Bugfixes over KDE 4.7.0
  * see http://kde.org/announcements/changelogs/changelog4_7_0to4_7_1.php for details
* Fri Jul 22 2011 dmueller@suse.de
- update to 4.7.0
  * Small fixes over KDE 4.7 RC2
  * see http://kde.org/announcements/4.7 for details
* Thu Jul 21 2011 idonmez@novell.com
- Update to 4.6.95
* Fri Jul  1 2011 dmueller@suse.de
- update to 4.6.5
  * Bugfixes over KDE 4.6.5
  * see http://kde.org/announcements/changelogs/changelog4_6_4to4_6_5.php for details
* Fri Jun  3 2011 dmueller@suse.de
- update to 4.6.4
  * Bugfixes over KDE 4.6.3
  * see http://kde.org/announcements/changelogs/changelog4_6_3to4_6_4.php for details
* Thu Apr 28 2011 dmueller@suse.de
- update to 4.6.3
  * Bugfixes over KDE 4.6.2
  * see http://kde.org/announcements/changelogs/changelog4_6_2to4_6_3.php for details
* Fri Apr  1 2011 dmueller@suse.de
- update to 4.6.2
  * Bugfixes over KDE 4.6.1
  * see http://kde.org/announcements/changelogs/changelog4_6_1to4_6_2.php for details
* Tue Mar  8 2011 dmueller@suse.de
- update to 4.6.1
  * Bugfixes over KDE 4.6.0
  * see http://kde.org/announcements/changelogs/changelog4_6_0to4_6_1.php for details
* Thu Feb 17 2011 wstephenson@novell.com
- call update-mime-database in pre/post install scripts
* Wed Jan 19 2011 dmueller@suse.de
- update to 4.6.0
  * For highlights, see http://kde.org/announcements/4.6
* Wed Jan 12 2011 ctrippe@gmx.net
- Build okteta-devel which is required for the okteta kdevelop-plugin
  (bnc#656174)
* Tue Jan 11 2011 ctrippe@gmx.net
- BuildRequire binutils-devel to build kmtrace (bnc#663361)
* Tue Jan  4 2011 dmueller@suse.de
- update to 4.5.95
  * KDE 4.6 RC2
  * no upstream changelog available.
* Wed Dec 22 2010 dmueller@suse.de
- update to 4.5.90
  * KDE 4.6 RC1
  * no upstream changelog available.
* Wed Dec  8 2010 toddrme2178@gmail.com
- Add optional dependency
  * QCA2 -- Needed for most of the algorithms of the checksum tool in Okteta.
- Removed build tests for unsupported openSUSE versions (11.0 and earlier)
* Fri Dec  3 2010 dmueller@suse.de
- update to 4.5.85
  * KDE 4.6 Beta2
  * Final Beta before RC, various fixes from Beta1
  * no upstream changelog available.
* Fri Nov 19 2010 dmueller@suse.de
- update to 4.5.80
  * KDE 4.6 Beta1
  * no upstream changelog available.
  * KBugBuster was dropped because it was broken and unmaintained
* Thu Nov 11 2010 coolo@novell.com
- fix file list
* Thu Oct 28 2010 dmueller@suse.de
- update to 4.5.3
  * see http://kde.org/announcements/changelogs/changelog4_5_2to4_5_3.php for details
* Thu Sep 30 2010 dmueller@suse.de
- update to 4.5.2
  * see http://kde.org/announcements/changelogs/changelog4_5_1to4_5_2.php for details
* Sun Aug 29 2010 tittiatcoke@gmail.com
- Added additional build requirement for Antlr package. This will
  now allow the build of the po2xml binary (bnc#630625)
* Fri Aug 27 2010 dmueller@suse.de
- update to 4.5.1
  * see http://kde.org/announcements/changelogs/changelog4_5_0to4_5_1.php for details
* Thu Jul 29 2010 dmueller@suse.de
- update to 4.5.0
  * KDE 4.5.0 final (version bump over RC3)
* Fri Jul 23 2010 dmueller@suse.de
- update to 4.4.95
  * KDE 4.5 RC3 (not announced)
  * critical fixes for 4.5.0 release
* Fri Jul 16 2010 dmueller@suse.de
- update to 4.4.93svn1149349
* Wed Jul  7 2010 dmueller@suse.de
- update to 4.4.5
  * bugfixes over 4.4.4
  * see http://kde.org/announcements/changelogs/changelog4_4_4to4_4_5.php for details
* Fri Jun 18 2010 dmueller@suse.de
- update to 4.4.4
  * bugfixes over 4.4.3
  * see http://kde.org/announcements/changelogs/changelog4_4_3to4_4_ 4.php for details
  * for most modules only version number as a change (4_4_BRANCH.diff already contained the diff
* Mon May 17 2010 llunak@novell.com
- update 4_4_BRANCH.diff: various fixes, translation updates
* Thu Apr 29 2010 dmueller@suse.de
- update to 4.4.3
  * bugfixes over 4.4.2
  * see http://kde.org/announcements/changelogs/changelog4_4_2to4_4_3.php for details
* Fri Mar 26 2010 dmueller@suse.de
- update to 4.4.2
  * bugfixes over 4.4.1
  * see http://kde.org/announcements/changelogs/changelog4_4_1to4_4_2.php for details
* Fri Feb 26 2010 dmueller@suse.de
- update to 4.4.1
  * bugfixes over 4.4.0
  * see http://kde.org/announcements/changelogs/changelog4_4_0to4_4_1.php for details
* Thu Feb  4 2010 dmueller@suse.de
- update to 4.4.0
  * Critical bugfixes only over 4.3.98
  * see http://www.kde.org/announcements/4.4/ for general overview
* Sun Jan 31 2010 dmueller@suse.de
- update to 4.3.98
  * see http://www.kde.org/announcements/announce-4.4-rc3.php for details
* Wed Jan 20 2010 dmueller@suse.de
- update to 4.3.95
  * see http://www.kde.org/announcements/announce-4.4-rc2.php for details
* Wed Jan  6 2010 dmueller@suse.de
- update to 4.3.90
  * see http://www.kde.org/announcements/announce-4.4-rc1.php for details
* Fri Dec 18 2009 dmueller@suse.de
- update to 4.3.85
  * see http://www.kde.org/announcements/announce-4.4-beta2.php for details
* Fri Dec  4 2009 dmueller@suse.de
- update to 4.3.80 (KDE 4.4 Beta1):
  * see http://techbase.kde.org/Schedules/KDE4/4.4_Feature_Plan
* Mon Nov  2 2009 dmueller@suse.de
- update to 4.3.3
  * see http://kde.org/announcements/changelogs/changelog4_3_2to4_3_3.php for details
* Thu Sep 24 2009 beineri@opensuse.org
- update 4_3_BRANCH.diff: icon fixes and translation updates
* Fri Aug 28 2009 dmueller@suse.de
- update to 4.3.1
  * see http://kde.org/announcements/changelogs/changelog4_3_0to4_3_1.php for details
* Sun Aug 23 2009 tittiatcoke@gmail.com
- Added a patch to enable build by resolving two
    void-return-in-non-void-function errors
* Thu Aug 20 2009 beineri@opensuse.org
- kompare is no real VCS, don't have Development/ in default install
* Fri Jul 31 2009 llunak@suse.cz
- suggest ctags for kate (bnc#527074)
* Wed Jul 29 2009 dmueller@suse.de
- update to 4.3.0
  * see http://kde.org/announcements/4.3 for details
* Tue Jul 21 2009 dmueller@suse.de
- update to 4.2.98
* Thu Jul  9 2009 dmueller@suse.de
- update to 4.2.96
* Thu Jul  2 2009 beineri@opensuse.org
- make lokalize require python-kde4 (bnc#517869)
* Wed Jun 24 2009 dmueller@suse.de
- update to 4.2.95
* Sat Jun 20 2009 beineri@opensuse.org
- drop kde4- package prefixes
* Wed Jun  3 2009 dmueller@suse.de
- update to 4.2.90
* Wed May 27 2009 dmueller@suse.de
- update to 4.2.88svn973768
* Tue May 19 2009 dmueller@suse.de
- update to 4.2.87svn969966
* Mon May 18 2009 dmueller@suse.de
- update to 4.2.86svn967995
* Thu May 14 2009 dmueller@suse.de
- update to 4.2.85 (KDE 4.3 Beta1)
* Thu Apr 30 2009 dmueller@suse.de
- update to 4.2.3
  * see http://kde.org/announcements/changelogs/changelog4_2_2to4_2_3.php
* Thu Mar 26 2009 dmueller@suse.de
- update to 4.2.2
  * see http://kde.org/announcements/changelogs/changelog4_2_1to4_2_2.php
* Fri Feb 27 2009 dmueller@suse.de
- update to 4.2.1
  * see http://kde.org/announcements/changelogs/changelog4_2_0to4_2_1.php
* Thu Feb 19 2009 dmueller@suse.de
- update branch diff
* Thu Jan 22 2009 dmueller@suse.de
- update to 4.2.0
* Fri Jan 16 2009 dmueller@suse.de
- remove unnecessary patch
* Tue Jan 13 2009 dmueller@suse.de
- update to 4.1.96
* Fri Jan  9 2009 dmueller@suse.de
- update to 4.1.87 (KDE 4.2 Januar snapshot)
* Tue Dec 16 2008 dmueller@suse.de
- libical-devel isalready included by kdepimlibs-devel
* Tue Dec 16 2008 stbinner@suse.de
- versionized split-provides are not supported
* Sat Nov 29 2008 stbinner@suse.de
- fix build after removal of libical copy from kdepimlibs
* Thu Nov 20 2008 stbinner@suse.de
- add SLE provides
* Fri Oct 31 2008 dmueller@suse.de
- update to 4.1.3
  * see http://kde.org/announcements/changelogs/changelog4_1_2to4_1_3.php
* Thu Sep 25 2008 dmueller@suse.de
- update to 4.1.2
  * see http://kde.org/announcements/changelogs/changelog4_1_1to4_1_2.php
* Thu Aug 28 2008 dmueller@suse.de
- update to 4.1.1
  * see http://kde.org/announcements/changelogs/changelog4_1to4_1_1.php
* Wed Aug 13 2008 dmueller@suse.de
- branch diff update
* Wed Jul 23 2008 dmueller@suse.de
- update to 4.1.0
* Fri Jul 18 2008 dmueller@suse.de
- update to 4.0.99
* Fri Jul 11 2008 dmueller@suse.de
- update to 4.0.98
* Thu Jul  3 2008 dmueller@suse.de
- update to 4.0.85
* Mon Jun 30 2008 dmueller@suse.de
- add directory ownerships
* Thu Jun 26 2008 dmueller@suse.de
- update to 4.0.84
* Wed Jun 18 2008 dmueller@suse.de
- update to 4.0.83
* Sat Jun 14 2008 schwab@suse.de
- Use -mminimal-toc on ppc64.
* Tue Jun 10 2008 dmueller@suse.de
- update to 4.0.82
* Mon Jun  9 2008 dmueller@suse.de
- update to 4.0.81
* Thu May  1 2008 dmueller@suse.de
- update to 4.0.4
  * http://www.kde.org/announcements/changelogs/changelog4_0_3to4_0_4.php
* Mon Apr 21 2008 dmueller@suse.de
- branch diff update
  * fix time parsing in cervisia
* Thu Mar 27 2008 dmueller@suse.de
- update to 4.0.3
* Wed Feb 27 2008 dmueller@suse.de
- update to 4.0.2
* Fri Feb 15 2008 dmueller@suse.de
- update 4_0_BRANCH.diff
* Thu Jan 31 2008 dmueller@suse.de
- update to 4.0.1
* Sun Jan 20 2008 stbinner@suse.de
- update KDE_4_0_BRANCH.diff
* Sat Jan  5 2008 dmueller@suse.de
- update to 4.0
* Wed Jan  2 2008 stbinner@suse.de
- update to 3.97.2
* Sun Dec 16 2007 dmueller@suse.de
- update to 3.97.1
* Sat Dec  8 2007 dmueller@suse.de
- update to 3.97.0
* Sat Dec  8 2007 stbinner@suse.de
- fix build
* Tue Dec  4 2007 dmueller@suse.de
- update to 3.96.3
* Wed Nov 28 2007 dmueller@suse.de
- update to 3.96.2
* Wed Nov 21 2007 dmueller@suse.de
- update to 3.96.1
* Wed Nov 14 2007 dmueller@suse.de
- update to 3.96.0
* Wed Nov  7 2007 dmueller@suse.de
- update to 3.95.2
* Thu Nov  1 2007 dmueller@suse.de
- update to 3.95.1
* Wed Oct 31 2007 dmueller@suse.de
- update to KDE 4.0 Beta4
* Sat Oct 20 2007 dmueller@suse.de
- update to 3.94.1
* Thu Oct 11 2007 dmueller@suse.de
- udpate to KDE 4.0 Beta3
* Tue Oct  2 2007 stbinner@suse.de
- update to 3.93.0.svn720133
* Wed Sep 26 2007 stbinner@suse.de
- update to 3.93.0.svn717255
* Thu Sep 13 2007 stbinner@suse.de
- update to 3.93.0.svn712063
* Sat Sep  1 2007 stbinner@suse.de
- update to KDE 4.0 Beta 2
* Thu Aug 23 2007 stbinner@suse.de
- update to 3.92.0.svn703915
* Thu Aug 16 2007 stbinner@suse.de
- update to 3.92.0.svn700768
* Thu Aug  9 2007 stbinner@suse.de
- update to 3.92.0.svn697375
- fix file conflict
* Tue Aug  7 2007 stbinner@suse.de
- fix build after strigi update
* Sun Jul 29 2007 stbinner@suse.de
- update to KDE 4.0 Beta 1
* Thu Jul 12 2007 stbinner@suse.de
- update to 3.91.0.svn685971
* Sat Jun 23 2007 stbinner@suse.de
- update to 3.90.1.svn679147
* Fri Jun  8 2007 stbinner@suse.de
- update to 3.90.1.svn670093
* Fri Jun  1 2007 coolo@suse.de
- simplify spec file by using macros from kde4-filesystem
* Thu May 24 2007 stbinner@suse.de
- initial package in abuild
